Attribute VB_Name = "basCallBack"
Option Explicit

' By Herman Liu
'
' This code is to provide two extended MsgBox functions: MsgBoxMove and MsgBoxPause.
'
' (1) MsgBoxMove function allows you to display your message box at a location specified
'     by you:
'     Syntax: MsgBoxMove(hwnd, Message, Title, Buttons, X, Y)
'
' (2) MsgBoxPause function allows you to have the message box automatically disappear
'     after pausing for a number of seconds specified by you.
'     Syntax: MsgboxPause(hwnd, Message, Title, Buttons, Seconds)
'
' Same as Msgbox function, each is capable of returning the value of the button clicked.
'
' The project consists of two files: MsgBoxEx.bas and MsgBoxEx.frm.  The former is for
' the creation of the said functions and the latter for exemplifying the use of them.
'
' Usage: Include the MsgboxEx.bas (less than 50 lines in total) in your project and you
' have these two functions at your disposal.
'
' Converted to an ActiveX DLL  By The VB Guru http://kandkconsulting.tripod.com/VB/VBHome.htm
' 10/25/2000

'********************************************
'*  Constants                               *
'********************************************
Public Const NV_CLOSEMSGBOX = &H5000&
Public Const NV_MOVEMSGBOX = &H5001&
Public Const HWND_TOPMOST = -1
Public Const SWP_NOSIZE = &H1

'********************************************
'*  Types                                   *
'********************************************
Public Type RECT
    Left As Long
    Top As Long
    Right As Long
    Bottom As Long
End Type

'********************************************
'*  API Calls                               *
'********************************************

Public Declare Function MessageBox Lib "user32" Alias "MessageBoxA" (ByVal hwnd As Long, ByVal lpText As String, ByVal lpCaption As String, ByVal wType As Long) As Long

Public Declare Function FindWindow Lib "user32" Alias "FindWindowA" (ByVal lpClassName As String, ByVal lpWindowName As String) As Long

Public Declare Function SetWindowPos Lib "user32" (ByVal hwnd As Long, ByVal hWndInsertAfter As Long, ByVal x As Long, ByVal y As Long, ByVal cx As Long, ByVal cy As Long, ByVal wFlags As Long) As Long

Public Declare Function SetForegroundWindow Lib "user32" (ByVal hwnd As Long) As Long

Public Declare Function SetTimer Lib "user32" (ByVal hwnd As Long, ByVal nIDEvent As Long, ByVal uElapse As Long, ByVal lpTimerFunc As Long) As Long

Public Declare Function KillTimer Lib "user32" (ByVal hwnd As Long, ByVal nIDEvent As Long) As Long

Public Declare Function GetWindowRect Lib "user32" (ByVal hwnd As Long, lpRect As RECT) As Long

'********************************************
'*  Global Vars                             *
'********************************************
Public mTitle      As String
Public mX          As Long
Public mY          As Long
Public mPause      As Long
Public mHandle     As Long




Public Function NewTimerProc(ByVal hwnd As Long, ByVal Msg As Long, ByVal wparam As Long, ByVal lparam As Long) As Long
    
    KillTimer hwnd, wparam
    
    Select Case wparam
         Case NV_CLOSEMSGBOX
              ' A system class is a window class registered by the system which cannot
              ' be destroyed by a processed, e.g. #32768 (a menu), #32769 (desktop
              ' window), #32770 (dialog box), #32771 (task switch window).
             mHandle = FindWindow("#32770", mTitle)
             If mHandle <> 0 Then
                  SetForegroundWindow mHandle
                  SendKeys "{enter}"
             End If
             
        Case NV_MOVEMSGBOX
             mHandle = FindWindow("#32770", mTitle)
             If mHandle <> 0 Then
                  Dim w As Single, h As Single
                  Dim mBox As RECT
                  w = Screen.Width / Screen.TwipsPerPixelX
                  h = Screen.Height / Screen.TwipsPerPixelY
                  GetWindowRect mHandle, mBox
                  If mX > (w - (mBox.Right - mBox.Left) - 1) Then mX = (w - (mBox.Right - mBox.Left) - 1)
                  If mY > (h - (mBox.Bottom - mBox.Top) - 1) Then mY = (h - (mBox.Bottom - mBox.Top) - 1)
                  If mX < 1 Then mX = 1: If mY < 1 Then mY = 1
                    ' SWP_NOSIZE is to use current size, ignoring 3rd & 4th parameters.
                  SetWindowPos mHandle, HWND_TOPMOST, mX, mY, 0, 0, SWP_NOSIZE
             End If
    End Select
End Function





